library(tidyverse)
library(texreg)

readme_rdd <- readRDS("final_models/0624_readme_all_rdd.rda")
contrib_rdd <- readRDS("final_models/0624_contrib_all_rdd.rda")
summary(readme_rdd)

texreg(list(readme_rdd, contrib_rdd), stars=NULL, digits=3, use.packages=FALSE, 
       custom.model.names=c( 'README','CONTRIBUTING'),
       custom.coef.names=c('(Intercept)', 'Indtroduction', 'Week (Time)', 'Project Age', 'Introduction:Week', 'Event Gap'), 
       table=FALSE, ci.force = TRUE)

readme_groupings <- read.csv('../final_data/deb_readme_interaction_groupings.csv')
contrib_groupings <- read.csv('../final_data/deb_contrib_interaction_groupings.csv')

subdirColors <-
  setNames( c('firebrick1', 'forestgreen', 'cornflowerblue')
            , c(0,1,2)  )

readme_g <- readme_groupings |> 
  ggplot(aes(x=rank, y=estimate, col = as.factor(ranef_grouping))) +
  geom_linerange(aes(ymin= conf.low, ymax= conf.high)) +
  scale_color_manual(values = subdirColors) + 
  guides(fill="none", color="none")+
  theme_bw()
readme_g


contrib_g <- contrib_groupings |> 
  ggplot(aes(x=rank, y=estimate, col = as.factor(ranef_grouping))) +
  geom_linerange(aes(ymin= conf.low, ymax= conf.high)) +
  scale_color_manual(values = subdirColors) + 
  theme_bw() +
  theme(legend.position = "top") 
contrib_g

library(gridExtra)
grid.arrange(contrib_g, readme_g, nrow = 1)
library(jtools)
plot_summs(readme_rdd, contrib_rdd, plot.distributions = TRUE)
?plot_summs

